@@ -233,8 +233,19 @@ KTorrent::KTorrent()
 	{
 		show();
 	}
+
+	bool menubar_hidden = KGlobal::config()->readBoolEntry("menubar_hidden",false);
+	menuBar()->setHidden(menubar_hidden);
+	m_menubarAction->setChecked(!menubar_hidden);
+
+	bool statusbar_hidden = KGlobal::config()->readBoolEntry("statusbar_hidden",false);
+	statusBar()->setHidden(statusbar_hidden);
+	m_statusbarAction->setChecked(!statusbar_hidden);
+
 	MaximizeLimits();
 	connect(&m_status_msg_expire,SIGNAL(timeout()),this,SLOT(statusBarMsgExpired()));
+	
+	m_view_man->updateActions();
 }
 
 KTorrent::~KTorrent()
@@ -265,7 +276,7 @@ void KTorrent::openView(kt::Group* g)
 	connect(v,SIGNAL(wantToRemove(kt::TorrentInterface*,bool )),
 			m_core,SLOT(remove(kt::TorrentInterface*,bool )));
 
-	connect(v,SIGNAL(dropped(QDropEvent*,QListViewItem*)),
+	connect(v->listView(),SIGNAL(dropped(QDropEvent*,QListViewItem*)),
 			this,SLOT(urlDropped(QDropEvent*,QListViewItem*)));
 	
 	connect(v,SIGNAL(wantToStart( kt::TorrentInterface* )),
@@ -277,8 +288,8 @@ void KTorrent::openView(kt::Group* g)
 	connect(v,SIGNAL(needsDataCheck( kt::TorrentInterface* )),
 			m_core,SLOT(doDataCheck( kt::TorrentInterface* )));
 	
-	connect(v,SIGNAL(updateActions( bool, bool, bool, bool )),
-			this,SLOT(onUpdateActions( bool, bool, bool, bool )));
+	connect(v,SIGNAL(updateActions( int )),
+			this,SLOT(onUpdateActions( int )));
 	
 	//connect Core queue() with queue() from KTView.
 	connect(v, SIGNAL(queue( kt::TorrentInterface* )), 
@@ -380,7 +391,8 @@ void KTorrent::applySettings(bool change_port)
 	net::SocketMonitor::setUploadCap(Settings::maxUploadRate()*1024);
 	net::SocketMonitor::setSleepTime(Settings::cpuUsage());
 	m_core->setKeepSeeding(Settings::keepSeeding());
-	mse::StreamSocket::setTOS(Settings::typeOfService());
+	mse::StreamSocket::setTOS(Settings::dSCP() << 2);
+	mse::StreamSocket::setMaxConnecting(Settings::maxConnectingSockets());
 	if (Settings::allwaysDoUploadDataCheck())
 		ChunkManager::setMaxChunkSizeForDataCheck(0);
 	else
@@ -433,7 +445,7 @@ void KTorrent::applySettings(bool change_port)
 	dht::DHTBase & ht = Globals::instance().getDHT();
 	if (Settings::dhtSupport() && !ht.isRunning())
 	{
-		ht.start(kt::DataDir() + "dht_table",Settings::dhtPort());
+		ht.start(kt::DataDir() + "dht_table",kt::DataDir() + "dht_key",Settings::dhtPort());
 	}
 	else if (!Settings::dhtSupport() && ht.isRunning())
 	{
@@ -443,7 +455,7 @@ void KTorrent::applySettings(bool change_port)
 	{
 		Out(SYS_GEN|LOG_NOTICE) << "Restarting DHT with new port " << Settings::dhtPort() << endl;
 		ht.stop();
-		ht.start(kt::DataDir() + "dht_table",Settings::dhtPort());
+		ht.start(kt::DataDir() + "dht_table",kt::DataDir() + "dht_key",Settings::dhtPort());
 	}
 	
 	if (Settings::useEncryption())
@@ -466,13 +478,15 @@ void KTorrent::loadSilently(const KURL& url)
 	m_core->loadSilently(url);
 }
 
-void KTorrent::onUpdateActions(bool can_start,bool can_stop,bool can_remove,bool can_scan)
+void KTorrent::onUpdateActions(int flags)
 {
-	m_start->setEnabled(can_start);
-	m_stop->setEnabled(can_stop);
-	m_remove->setEnabled(can_remove);
-	m_queueaction->setEnabled(can_remove);
-	m_datacheck->setEnabled(can_scan);
+	m_start->setEnabled(flags & KTorrentView::START);
+	m_stop->setEnabled(flags & KTorrentView::STOP);
+	m_remove->setEnabled(flags & KTorrentView::REMOVE);
+	m_queueaction->setEnabled(flags & KTorrentView::REMOVE);
+	m_datacheck->setEnabled(flags & KTorrentView::SCAN);
+	m_startall->setEnabled(flags & KTorrentView::START_ALL);
+	m_stopall->setEnabled(flags & KTorrentView::STOP_ALL);
 }
 
 void KTorrent::currentTorrentChanged(kt::TorrentInterface* tc)
@@ -490,6 +504,7 @@ void KTorrent::setupActions()
 	KStdAction::paste(kapp,SLOT(paste()),actionCollection());
 
 	m_statusbarAction = KStdAction::showStatusbar(this, SLOT(optionsShowStatusbar()), actionCollection());
+	m_menubarAction = KStdAction::showMenubar(this, SLOT(optionsShowMenubar()), actionCollection()); 
 
 	KStdAction::keyBindings(this, SLOT(optionsConfigureKeys()), actionCollection());
 	KStdAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), actionCollection());
@@ -509,13 +524,17 @@ void KTorrent::setupActions()
 			actionCollection(), "Remove");
 	
 	m_startall = new KAction(
-			i18n("to start all", "Start All"), "ktstart_all",0,this, SLOT(startAllDownloads()),
+			i18n("to start all", "Start All"), "ktstart_all",0,this, SLOT(startAllDownloadsCurrentView()),
 			actionCollection(), "Start all");
 	
+	m_startall_systray = new KAction(i18n("to start all", "Start All"), "ktstart_all",0,this, SLOT(startAllDownloads()),actionCollection());
+	
 	m_stopall = new KAction(
-			i18n("to stop all", "Stop All"), "ktstop_all",0,this, SLOT(stopAllDownloads()),
+			i18n("to stop all", "Stop All"), "ktstop_all",0,this, SLOT(stopAllDownloadsCurrentView()),
 			actionCollection(), "Stop all");
 	
+	m_stopall_systray = new KAction(i18n("to stop all", "Stop All"), "ktstop_all",0,this, SLOT(stopAllDownloads()),actionCollection());
+	
 	m_pasteurl = new KAction(
 			i18n("to paste torrent URL", "Paste Torrent URL..."), "ktstart",0,this, SLOT(torrentPaste()),
 			actionCollection(), "paste_url");
@@ -539,9 +558,11 @@ void KTorrent::setupActions()
 			i18n("Check Data Integrity"),
 	QString::null,0,m_view_man,SLOT(checkDataIntegrity()),actionCollection(),"check_data");
 	
+	m_find = KStdAction::find(this,SLOT(find()),actionCollection());
+	
 	//Plug actions to systemtray context menu
-	m_startall->plug(m_systray_icon->contextMenu());
-	m_stopall->plug(m_systray_icon->contextMenu());
+	m_startall_systray->plug(m_systray_icon->contextMenu());
+	m_stopall_systray->plug(m_systray_icon->contextMenu());
 	m_systray_icon->contextMenu()->insertSeparator();
 	m_pasteurl->plug(m_systray_icon->contextMenu());
 	m_systray_icon->contextMenu()->insertSeparator();
@@ -574,12 +595,13 @@ bool KTorrent::queryClose()
 
 bool KTorrent::queryExit()
 {
-	m_group_view->saveGroups();
 	// stop timers to prevent update
 	m_gui_update_timer.stop();
 	
 	KGlobal::config()->setGroup("WindowStatus");
-	KGlobal::config()->writeEntry( "hidden_on_exit",this->isHidden());
+	KGlobal::config()->writeEntry("hidden_on_exit",this->isHidden());
+	KGlobal::config()->writeEntry("menubar_hidden",menuBar()->isHidden());
+	KGlobal::config()->writeEntry("statusbar_hidden",statusBar()->isHidden());
 	m_view_man->saveViewState(KGlobal::config());
 	saveSettings();
 	hide();
@@ -627,11 +649,16 @@ void KTorrent::startDownload()
 	currentTorrentChanged(tc);
 }
 
-void KTorrent::startAllDownloads()
+void KTorrent::startAllDownloadsCurrentView()
 {
 	m_view_man->startAllDownloads();
 }
 
+void KTorrent::startAllDownloads()
+{
+	m_core->startAll(3);
+}
+
 void KTorrent::stopDownload()
 {
 	m_view_man->stopDownloads();
@@ -640,6 +667,11 @@ void KTorrent::stopDownload()
 }
 
 void KTorrent::stopAllDownloads()
+{
+	m_core->stopAll(3);
+}
+
+void KTorrent::stopAllDownloadsCurrentView()
 {
 	m_view_man->stopAllDownloads();
 }
@@ -660,6 +692,16 @@ void KTorrent::optionsShowStatusbar()
 		statusBar()->hide();
 }
 
+void KTorrent::optionsShowMenubar()
+{
+	// this is all very cut and paste code for showing/hiding the
+	// menubar
+	if (m_menubarAction->isChecked())
+		menuBar()->show();
+	else
+		menuBar()->hide();
+}
+
 void KTorrent::optionsConfigureKeys()
 {
 	KKeyDialog::configure(actionCollection());
@@ -723,22 +765,10 @@ void KTorrent::changeCaption(const QString& text)
 
 void KTorrent::saveProperties(KConfig* )
 {
-	KGlobal::config()->writeEntry( "hidden_on_exit",this->isHidden());
-	KGlobal::config()->sync();
 }
 
 void KTorrent::readProperties(KConfig*)
 {
-	bool hidden_on_exit = KGlobal::config()->readBoolEntry("hidden_on_exit",false);
-	if (!(Settings::showSystemTrayIcon() && hidden_on_exit))
-	{
-		Out(SYS_GEN|LOG_DEBUG) << "Showing KT" << endl;
-		show();
-	}
-	else
-	{
-		hide();
-	}
 }
 
 void KTorrent::urlDropped(QDropEvent* event,QListViewItem*)
@@ -754,8 +784,8 @@ void KTorrent::urlDropped(QDropEvent* event,QListViewItem*)
 
 void KTorrent::updatedStats()
 {
-	m_startall->setEnabled(m_core->getNumTorrentsNotRunning() > 0);
-	m_stopall->setEnabled(m_core->getNumTorrentsRunning() > 0);
+	m_startall_systray->setEnabled(m_core->getNumTorrentsNotRunning() > 0);
+	m_stopall_systray->setEnabled(m_core->getNumTorrentsRunning() > 0);
 	
 	CurrentStats stats = this->m_core->getStats();
 	
@@ -976,5 +1006,12 @@ void KTorrent::statusBarMsgExpired()
 	m_statusInfo->clear();
 }
 
+void KTorrent::find()
+{
+	KTorrentView* v = m_view_man->getCurrentView();
+	if (v)
+		v->toggleFilterBar();
+}
+
 #include "ktorrent.moc"
 
