@@ -40,6 +40,7 @@
 #include <qcursor.h>
 #include <qheader.h>
 #include <qvaluelist.h>
+#include <qlayout.h>
 		
 #include "ktorrentview.h"
 #include "ktorrentviewitem.h"
@@ -48,33 +49,67 @@
 #include "addpeerwidget.h"
 #include "ktorrentviewmenu.h"
 #include "speedlimitsdlg.h"
+#include "filterbar.h"
 
 using namespace bt;
 using namespace kt;
 
-KTorrentView::KTorrentView(QWidget *parent)
-	: KListView(parent),menu(0),current_group(0),running(0),total(0)
-{
 
+TorrentView::TorrentView(KTorrentView* parent) : KListView(parent),ktview(parent)
+{}
+	
+TorrentView::~TorrentView() 
+{}
+	
+bool TorrentView::eventFilter(QObject* watched, QEvent* e)
+{
+	if((QHeader*)watched == header())
+	{
+		switch(e->type())
+		{
+			case QEvent::MouseButtonPress:
+			{
+				if(static_cast<QMouseEvent *>(e)->button() == RightButton)
+					ktview->m_headerMenu->popup(QCursor::pos());
+
+				break;
+			}
+			default:
+				break;
+		}
+	}
+
+	return KListView::eventFilter(watched, e);
+}
+
+KTorrentView::KTorrentView(QWidget *parent)
+	: QWidget(parent),menu(0),current_group(0),running(0),total(0),view(0),filter_bar(0)
+{
+	QVBoxLayout* layout = new QVBoxLayout(this);
+	layout->setAutoAdd(true);
+	view = new TorrentView(this);
+	filter_bar = new FilterBar(this);
+	filter_bar->setHidden(true);
+	
 	setupColumns();
 	
-	connect(this,SIGNAL(executed(QListViewItem* )),
+	connect(view,SIGNAL(executed(QListViewItem* )),
 			this,SLOT(onExecuted(QListViewItem* )));
 	
-	connect(this,SIGNAL(currentChanged(QListViewItem* )),
+	connect(view,SIGNAL(currentChanged(QListViewItem* )),
 			this,SLOT(onExecuted(QListViewItem* )));
 	
-	connect(this,SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint& )),
+	connect(view,SIGNAL(contextMenu(KListView*, QListViewItem*, const QPoint& )),
 			this,SLOT(showContextMenu(KListView*, QListViewItem*, const QPoint& )));
 	
-	connect(this,SIGNAL(selectionChanged()),this,SLOT(onSelectionChanged()));
+	connect(view,SIGNAL(selectionChanged()),this,SLOT(onSelectionChanged()));
 
 	menu = new KTorrentViewMenu(this);
 	connect(menu,SIGNAL(groupItemActivated(const QString&)),this,SLOT(gsmItemActived(const QString&)));
 	
 	connect(m_headerMenu, SIGNAL(activated(int)), this, SLOT(onColumnVisibilityChange( int )));
 
-	setFrameShape(QFrame::NoFrame);
+	view->setFrameShape(QFrame::NoFrame);
 }
 
 KTorrentView::~KTorrentView()
@@ -85,14 +120,14 @@ void KTorrentView::insertColumn(QString label, Qt::AlignmentFlags align)
 {
 	m_headerMenu->insertItem(label);
 		
-	int ind = addColumn(label);
-	setColumnAlignment(ind, align);
+	int ind = view->addColumn(label);
+	view->setColumnAlignment(ind, align);
 }
 
 void KTorrentView::setupColumns()
 {
 		//Header menu
-	m_headerMenu = new KPopupMenu(this);
+	m_headerMenu = new KPopupMenu(view);
 	m_headerMenu->setCheckable(true);
 	m_headerMenu->insertTitle(i18n("Visible columns"));
 	
@@ -111,14 +146,14 @@ void KTorrentView::setupColumns()
 	insertColumn(i18n("Time Downloaded"), Qt::AlignRight);	
 	insertColumn(i18n("Time Seeded"), Qt::AlignRight);
 	
-	setAllColumnsShowFocus(true);
-	setShowSortIndicator(true);
-	setAcceptDrops(true);
-	setSelectionMode(QListView::Extended);
-	for (Uint32 i = 0;i < (Uint32)columns();i++)
+	view->setAllColumnsShowFocus(true);
+	view->setShowSortIndicator(true);
+	view->setAcceptDrops(true);
+	view->setSelectionMode(QListView::Extended);
+	for (Uint32 i = 0;i < (Uint32)view->columns();i++)
 	{
-		setColumnWidth(i, 100);
-		setColumnWidthMode(i,QListView::Manual);
+		view->setColumnWidth(i, 100);
+		view->setColumnWidthMode(i,QListView::Manual);
 	}
 }
 
@@ -167,27 +202,34 @@ void KTorrentView::setCurrentGroup(Group* group)
 	else
 		setCaption(i18n("All Torrents %1/%2").arg(running).arg(total));
 	
-	onExecuted(currentItem());
+	onSelectionChanged();
+	onExecuted(view->currentItem());
 }
 
 void KTorrentView::saveSettings(KConfig* cfg,int idx)
 {
-	saveLayout(cfg,QString("KTorrentView-%1").arg(idx));
+	QString group = QString("KTorrentView-%1").arg(idx);
+	view->saveLayout(cfg,group);
+	cfg->setGroup(group);
+	filter_bar->saveSettings(cfg);
 }
 
 
 void KTorrentView::loadSettings(KConfig* cfg,int idx)
 {
-	restoreLayout(cfg,QString("KTorrentView-%1").arg(idx));
-	setDragEnabled(true);
+	QString group = QString("KTorrentView-%1").arg(idx);
+	view->restoreLayout(cfg,group);
+	view->setDragEnabled(true);
 
-	for(int i=0; i<columns();++i)
+	for(int i=0; i < view->columns();++i)
 	{
 		bool visible = columnVisible(i);
 		
 		m_headerMenu->setItemChecked(m_headerMenu->idAt(i+1), visible);
-		header()->setResizeEnabled(visible, i);
+		view->header()->setResizeEnabled(visible, i);
 	}
+	cfg->setGroup(group);
+	filter_bar->loadSettings(cfg);
 }
 
 
@@ -230,7 +272,9 @@ bool KTorrentView::startDownload(kt::TorrentInterface* tc)
 void KTorrentView::stopDownload(kt::TorrentInterface* tc)
 {
 	if (tc && tc->getStats().running)
+	{
 		wantToStop(tc,true);
+	}
 }
 
 void KTorrentView::showStartError()
@@ -247,7 +291,7 @@ void KTorrentView::startDownloads()
 {
 	bool err = false;
 	
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -268,7 +312,7 @@ void KTorrentView::startDownloads()
 	
 void KTorrentView::stopDownloads()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -297,6 +341,7 @@ void KTorrentView::startAllDownloads()
 		showStartError();
 	}
 	*/
+	onSelectionChanged();
 }
 
 void KTorrentView::stopAllDownloads()
@@ -310,11 +355,12 @@ void KTorrentView::stopAllDownloads()
 	
 		i++;
 	}
+	onSelectionChanged();
 }
 	
 void KTorrentView::removeDownloads()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -324,7 +370,7 @@ void KTorrentView::removeDownloads()
 		{	
 			const TorrentStats & s = tc->getStats();
 			bool data_to = false;
-			if (s.bytes_left_to_download > 0)
+			if (!s.completed)
 			{
 				QString msg = i18n("The torrent %1 has not finished downloading, "
 						"do you want to delete the incomplete data, too?").arg(s.torrent_name);
@@ -352,7 +398,7 @@ void KTorrentView::removeDownloadsAndData()
             KStdGuiItem::cancel()) == KMessageBox::No)
 		return;
 	
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -367,7 +413,7 @@ void KTorrentView::removeDownloadsAndData()
 
 void KTorrentView::manualAnnounce()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -379,7 +425,7 @@ void KTorrentView::manualAnnounce()
 
 void KTorrentView::previewFiles() 
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -394,7 +440,7 @@ void KTorrentView::previewFiles()
 
 TorrentInterface* KTorrentView::getCurrentTC()
 {
-	KTorrentViewItem* tvi = dynamic_cast<KTorrentViewItem*>(currentItem());
+	KTorrentViewItem* tvi = dynamic_cast<KTorrentViewItem*>(view->currentItem());
 	if (tvi)
 		return tvi->getTC();
 	else
@@ -445,7 +491,7 @@ void KTorrentView::removeTorrent(TorrentInterface* tc)
 		KTorrentViewItem* tvi = i.data();
 		items.erase(i);
 		delete tvi;
-		tvi = dynamic_cast<KTorrentViewItem*>(currentItem());
+		tvi = dynamic_cast<KTorrentViewItem*>(view->currentItem());
 		if (tvi)
 			currentChanged(tvi->getTC());
 		else
@@ -466,18 +512,19 @@ void KTorrentView::update()
 		KTorrentViewItem* tvi = i.data();
 		if (tvi)
 			tvi->update();
-		
-		
 		// check if the torrent still is part of the group
 		kt::TorrentInterface* ti = i.key();
-		if (tvi && current_group && !current_group->isMember(ti))
+		
+		bool member = (current_group->isMember(ti) && filter_bar->matchesFilter(ti));
+		
+		if (tvi && current_group && !member)
 		{
 			// torrent is no longer a member of this group so remove it from the view
 			delete tvi;
 			i.data() = 0;
 			count = false;
 		}
-		else if (!tvi && (!current_group || current_group->isMember(ti)))
+		else if (!tvi && (!current_group || member))
 		{
 			tvi = new KTorrentViewItem(this,ti);
 			i.data() = tvi;
@@ -502,9 +549,10 @@ void KTorrentView::update()
 			setCaption(QString("%1 %2/%3").arg(current_group->groupName()).arg(running).arg(total));
 		else
 			setCaption(i18n("All Torrents %1/%2").arg(running).arg(total));
+		onSelectionChanged();
 	}
 	
-	sort();
+	view->sort();
 }
 
 bool KTorrentView::acceptDrag(QDropEvent* event) const
@@ -515,9 +563,9 @@ bool KTorrentView::acceptDrag(QDropEvent* event) const
 
 void KTorrentView::onSelectionChanged()
 {
-	bool en_start = false;
-	bool en_stop = false;
-	QPtrList<QListViewItem> sel = selectedItems();
+	int flags = 0;
+	
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -527,18 +575,33 @@ void KTorrentView::onSelectionChanged()
 		{
 			const TorrentStats & s = tc->getStats();
 			if (!s.running)
-				en_start = true;
+				flags |= START;
 			else
-				en_stop = true;
+				flags |= STOP;
+			
+			if (flags & (START|STOP))
+				break;
 		}
 	}
 	
-	updateActions(en_start,en_stop,sel.count() > 0,sel.count() == 1);
+	if (sel.count() > 0)
+		flags |= REMOVE;
+	
+	if (sel.count() == 1)
+		flags |= SCAN;
+	
+	if (running > 0)
+		flags |= STOP_ALL;
+	
+	if (running == 0 && total > 0)
+		flags |= START_ALL;
+	
+	updateActions(flags);
 }
 
 void KTorrentView::queueSlot()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -552,7 +615,7 @@ void KTorrentView::queueSlot()
 
 void KTorrentView::checkDataIntegrity()
 {	
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	if (sel.count() == 0)
 		return;
 	
@@ -571,7 +634,7 @@ void KTorrentView::checkDataIntegrity()
 
 QDragObject* KTorrentView::dragObject()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	if (sel.count() == 0)
 		return 0;
 	 
@@ -580,7 +643,7 @@ QDragObject* KTorrentView::dragObject()
 
 void KTorrentView::getSelection(QValueList<kt::TorrentInterface*> & sel)
 {
-	QPtrList<QListViewItem> s = selectedItems();
+	QPtrList<QListViewItem> s = view->selectedItems();
 	if (s.count() == 0)
 		return;
 	
@@ -596,7 +659,7 @@ void KTorrentView::getSelection(QValueList<kt::TorrentInterface*> & sel)
 
 void KTorrentView::removeFromGroup()
 {
-	QPtrList<QListViewItem> s = selectedItems();
+	QPtrList<QListViewItem> s = view->selectedItems();
 	if (s.count() == 0 || !current_group || current_group->isStandardGroup())
 		return;
 	
@@ -614,7 +677,7 @@ void KTorrentView::removeFromGroup()
 
 void KTorrentView::addSelectionToGroup(kt::Group* g)
 {
-	QPtrList<QListViewItem> s = selectedItems();
+	QPtrList<QListViewItem> s = view->selectedItems();
 	if (s.count() == 0 || !g)
 		return;
 	
@@ -630,7 +693,7 @@ void KTorrentView::addSelectionToGroup(kt::Group* g)
 
 void KTorrentView::showAddPeersWidget()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -646,7 +709,7 @@ void KTorrentView::showAddPeersWidget()
 
 void KTorrentView::openOutputDirectory()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -663,7 +726,7 @@ void KTorrentView::openOutputDirectory()
 
 void KTorrentView::openTorXDirectory()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -677,7 +740,7 @@ void KTorrentView::openTorXDirectory()
 
 void KTorrentView::setDownloadLocationSlot()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -685,7 +748,7 @@ void KTorrentView::setDownloadLocationSlot()
 		if (tc)
 		{
 			QString dn;
-			dn = KFileDialog::getExistingDirectory(QString::null, this, i18n("Choose download location for %1").arg(tc->getStats().torrent_name));
+			dn = KFileDialog::getExistingDirectory(tc->getStats().output_path, this, i18n("Choose download location for %1").arg(tc->getStats().torrent_name));
 								
 			if(dn.isNull() || dn.isEmpty())
 				continue;
@@ -701,7 +764,7 @@ void KTorrentView::setDownloadLocationSlot()
 
 void KTorrentView::dhtSlot()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -717,7 +780,7 @@ void KTorrentView::dhtSlot()
 
 void KTorrentView::utPexSlot()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	for (QPtrList<QListViewItem>::iterator itr = sel.begin(); itr != sel.end();itr++)
 	{
 		KTorrentViewItem* kvi = (KTorrentViewItem*)*itr;
@@ -733,7 +796,7 @@ void KTorrentView::utPexSlot()
 
 void KTorrentView::speedLimits()
 {
-	QPtrList<QListViewItem> sel = selectedItems();
+	QPtrList<QListViewItem> sel = view->selectedItems();
 	if (sel.count() != 1)
 		return;
 	
@@ -747,19 +810,22 @@ void KTorrentView::speedLimits()
 
 void KTorrentView::columnHide(int index)
 {
-	hideColumn(index);
-	header()->setResizeEnabled(FALSE, index);
+	view->hideColumn(index);
+	view->header()->setResizeEnabled(FALSE, index);
 }
 
 void KTorrentView::columnShow(int index)
 {
-	setColumnWidth(index, 100);
-	header()->setResizeEnabled(TRUE, index);
+	view->setColumnWidth(index, 100);
+	view->header()->setResizeEnabled(TRUE, index);
 }
 
 bool KTorrentView::columnVisible(int index)
 {
-	return columnWidth(index) != 0;
+	if (index < view->columns() && index >= 0) 
+		return view->columnWidth(index) != 0;
+	else
+		return true;
 }
 
 void KTorrentView::onColumnVisibilityChange(int id)
@@ -778,28 +844,6 @@ void KTorrentView::onColumnVisibilityChange(int id)
 		columnHide(mid);
 }
 
-bool KTorrentView::eventFilter(QObject* watched, QEvent* e)
-{
-	if((QHeader*)watched == header())
-	{
-		switch(e->type())
-		{
-				case QEvent::MouseButtonPress:
-				{
-					if(static_cast<QMouseEvent *>(e)->
-					        button() == RightButton)
-						m_headerMenu->popup(QCursor::pos());
-
-					break;
-				}
-				default:
-				break;
-		}
-	}
-
-	return KListView::eventFilter(watched, e);
-}
-
 void KTorrentView::gsmItemActived(const QString & group)
 {
 	groupsSubMenuItemActivated(this,group);
@@ -850,14 +894,19 @@ void KTorrentView::setupViewColumns()
 	}
 	
 	// make sure menu is OK
-	for(int i=0; i<columns();++i)
+	for(int i=0; i< view->columns();++i)
 	{
 		bool visible = columnVisible(i);
 		m_headerMenu->setItemChecked(m_headerMenu->idAt(i+1), visible);
-		header()->setResizeEnabled(visible, i);
+		view->header()->setResizeEnabled(visible, i);
 	}
 }
 
 
 
+void KTorrentView::toggleFilterBar()
+{
+	filter_bar->setHidden(!filter_bar->isHidden());
+}
+
 #include "ktorrentview.moc"
