@@ -46,9 +46,6 @@ namespace bt
 	{
 		Peer* peer;
 		QValueList<Request> requests;
-		Uint32 rone_time;
-		std::set<Uint32> allowed_fast;
-		bool can_generate_af;
 		Uint32 uploaded;
 	public:
 		/**
@@ -58,9 +55,6 @@ namespace bt
 		PeerUploader(Peer* peer);
 		virtual ~PeerUploader();
 		
-		/// Enable the allowed fast set
-		void enableAllowedFast();
-		
 		/**
 		 * Add a Request to the list of Requests.
 		 * @param r The Request
@@ -83,10 +77,8 @@ namespace bt
 		Uint32 update(ChunkManager & cman,Uint32 opt_unchoked);
 		
 		/// Get the number of requests
-		Uint32 getNumRequests() const {return requests.count();}
-		
-		/// Reject all packets
-		void rejectAll();
+		Uint32 getNumRequests() const;
+				
 		
 		void addUploadedBytes(Uint32 bytes) {uploaded += bytes;}
 		
@@ -94,8 +86,6 @@ namespace bt
 		 * Clear all pending requests.
 		 */
 		void clearAllRequests();
-	private:
-		void generateAF(ChunkManager & cman);
 	};
 
 }
